@@ -10,18 +10,15 @@ import typing_extensions
 
 from typeguard import check_type
 
-import aws_cdk.aws_ec2._jsii
-import aws_cdk.aws_ecs._jsii
-import aws_cdk.aws_s3._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-fargate-s3",
-    "1.173.0",
+    "2.13.0",
     __name__[0:-6],
-    "aws-fargate-s3@1.173.0.jsii.tgz",
+    "aws-fargate-s3@2.13.0.jsii.tgz",
 )
 
 __all__ = [
